@@ -14,16 +14,16 @@ Version 0.0101
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use base 'Games::Solitaire::Verify::Base';
 
 use Games::Solitaire::Verify::Exception;
 use Games::Solitaire::Verify::Card;
 
-__PACKAGE__->mk_accessors(qw(
+__PACKAGE__->mk_acc_ref([qw(
     _cards
-    ));
+    )]);
 
 =head1 SYNOPSIS
 
