@@ -14,20 +14,20 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use base 'Games::Solitaire::Verify::Base';
 
 use Games::Solitaire::Verify::Exception;
 
-__PACKAGE__->mk_accessors(qw(
+__PACKAGE__->mk_acc_ref([qw(
     source_type
     dest_type
     source
     dest
     num_cards
     _game
-    ));
+    )]);
 
 =head1 SYNOPSIS
 
@@ -126,6 +126,30 @@ sub _init
     }
 }
 
+=head1 METHODS
+
+=head2 $move->source_type()
+
+Accessor for the solitaire card game's board layout's type - 
+C<"stack">, C<"freecell">, etc. used in the layout.
+
+=head2 $move->dest_type()
+
+Accessor for the destination type - C<"stack">, C<"freecell">, 
+C<"destination">.
+
+=head2 $move->source()
+
+The index number of the source.
+
+=head2 $move->dest()
+
+The index number of the destination.
+
+=head2 $move->num_cards()
+
+Number of cards affects - only relevant for a stack-to-stack move usually.
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at iglu.org.il> >>
